==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QResizeEvent_shell.cpp <==
#include "QResizeEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QResizeEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QResizeEvent")
    QResizeEvent *_ptr = reinterpret_cast<QResizeEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QResizeEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QResizeEvent_shell) ); }

jmethodID QResizeEvent_shell::__shell_javaMethod(int pos) const { return QResizeEvent_shell::__shell()->javaMethod(typeid(QResizeEvent), pos); }

// emitting (writeShellConstructor)
QResizeEvent_shell::QResizeEvent_shell(const QResizeEvent& arg__1)
    : QResizeEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QResizeEvent::QResizeEvent_shell(const QResizeEvent& arg__1)", QResizeEvent_shell::__shell())
    QResizeEvent_shell::__shell()->constructed(typeid(QResizeEvent));
}

QResizeEvent_shell::QResizeEvent_shell(const QSize& size0, const QSize& oldSize1)
    : QResizeEvent(size0, oldSize1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QResizeEvent::QResizeEvent_shell(const QSize& size0, const QSize& oldSize1)", QResizeEvent_shell::__shell())
    QResizeEvent_shell::__shell()->constructed(typeid(QResizeEvent));
}

// emitting (writeShellDestructor)
QResizeEvent_shell::~QResizeEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QResizeEvent::~QResizeEvent()", QResizeEvent_shell::__shell())
    QResizeEvent_shell::__shell()->destructed(typeid(QResizeEvent));
}

void QResizeEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QResizeEvent_shell*>(ptr)->QResizeEvent_shell::__shell()->tryDeleteShell(typeid(QResizeEvent));
}

// emitting Virtual overrides (virtualFunctions)
QResizeEvent* QResizeEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QResizeEvent::clone()const", QResizeEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QResizeEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QResizeEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QResizeEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QResizeEvent_shell::__shell()->warnForMethod("QResizeEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QResizeEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QResizeEvent::clone();
        }
    }else{
        return QResizeEvent::clone();
    }
}

void QResizeEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QResizeEvent::", QResizeEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QResizeEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QResizeEvent_shell::__shell()->warnForMethod("QResizeEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QResizeEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QResizeEvent_access::__qt_assign_cref_QResizeEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QResizeEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QResizeEvent>(__jni_env, other0);
    QResizeEvent::operator=(__qt_other0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QResizeEvent_access::__qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QResizeEvent* __qt_return_value = QResizeEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QResizeEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QResizeEvent(QResizeEvent)
void __qt_construct_QResizeEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QResizeEvent(QResizeEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QResizeEvent& __qt_arg__1 = qtjambi_cast<const QResizeEvent& >(__jni_env, arg__1);
    QResizeEvent *__qt_this = new(__qtjambi_ptr) QResizeEvent_shell(__qt_arg__1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QResizeEvent(QSize,QSize)
void __qt_construct_QResizeEvent_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QResizeEvent(QSize,QSize)")
    jobject size0 = __java_arguments[0].l;
    const QSize& __qt_size0 = qtjambi_cast<const QSize& >(__jni_env, size0);
    jobject oldSize1 = __java_arguments[1].l;
    const QSize& __qt_oldSize1 = qtjambi_cast<const QSize& >(__jni_env, oldSize1);
    QResizeEvent *__qt_this = new(__qtjambi_ptr) QResizeEvent_shell(__qt_size0, __qt_oldSize1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QResizeEvent_shell
void __qt_destruct_QResizeEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QResizeEvent")
    reinterpret_cast<QResizeEvent_shell*>(ptr)->~QResizeEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QResizeEvent::QResizeEvent(QResizeEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QResizeEvent_initialize_1native__Lio_qt_gui_QResizeEvent_2Lio_qt_gui_QResizeEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QResizeEvent::QResizeEvent(QResizeEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QResizeEvent_0, sizeof(QResizeEvent_shell), typeid(QResizeEvent), true, &deleter_QResizeEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QResizeEvent::QResizeEvent(QSize,QSize)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QResizeEvent_initialize_1native__Lio_qt_gui_QResizeEvent_2Lio_qt_core_QSize_2Lio_qt_core_QSize_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject size0,
 jobject oldSize1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QResizeEvent::QResizeEvent(QSize,QSize)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = size0;
        arguments[1].l = oldSize1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QResizeEvent_1, sizeof(QResizeEvent_shell), typeid(QResizeEvent), true, &deleter_QResizeEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QResizeEvent::oldSize()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QResizeEvent_oldSize_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QResizeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QResizeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QResizeEvent::oldSize()const", __qt_this)
        const QSize& __qt_return_value = __qt_this->oldSize();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QResizeEvent::operator=(QResizeEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QResizeEvent_assign_1native_1cref_1QResizeEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QResizeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QResizeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QResizeEvent::operator=(QResizeEvent)", __qt_this)
        static_cast<QResizeEvent_access*>(__qt_this)->__qt_assign_cref_QResizeEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QResizeEvent::size()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QResizeEvent_size_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QResizeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QResizeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QResizeEvent::size()const", __qt_this)
        const QSize& __qt_return_value = __qt_this->size();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QResizeEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QResizeEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QResizeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QResizeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QResizeEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QResizeEvent_access*>(__qt_this)->__qt_clone(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QResizeEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QResizeEvent>("QResizeEvent", "io/qt/gui/QResizeEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/gui/QResizeEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QResizeEvent, {
        ConstructorInfo(&__qt_construct_QResizeEvent_0, "Lio/qt/gui/QResizeEvent;")
       ,ConstructorInfo(&__qt_construct_QResizeEvent_1, "Lio/qt/core/QSize;Lio/qt/core/QSize;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QResizeEvent);
    registerSizeOfShell(typeId, sizeof(QResizeEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QResizeEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QResizeEvent_shell.cpp <==
#include "QResizeEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QResizeEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QResizeEvent")
    QResizeEvent *_ptr = reinterpret_cast<QResizeEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QResizeEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QResizeEvent_shell) ); }

jmethodID QResizeEvent_shell::__shell_javaMethod(int pos) const { return QResizeEvent_shell::__shell()->javaMethod(typeid(QResizeEvent), pos); }

// emitting (writeShellConstructor)
QResizeEvent_shell::QResizeEvent_shell(const QResizeEvent& arg__1)
    : QResizeEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QResizeEvent::QResizeEvent_shell(const QResizeEvent& arg__1)", QResizeEvent_shell::__shell())
    QResizeEvent_shell::__shell()->constructed(typeid(QResizeEvent));
}

QResizeEvent_shell::QResizeEvent_shell(const QSize& size0, const QSize& oldSize1)
    : QResizeEvent(size0, oldSize1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QResizeEvent::QResizeEvent_shell(const QSize& size0, const QSize& oldSize1)", QResizeEvent_shell::__shell())
    QResizeEvent_shell::__shell()->constructed(typeid(QResizeEvent));
}

// emitting (writeShellDestructor)
QResizeEvent_shell::~QResizeEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QResizeEvent::~QResizeEvent()", QResizeEvent_shell::__shell())
    QResizeEvent_shell::__shell()->destructed(typeid(QResizeEvent));
}

void QResizeEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QResizeEvent_shell*>(ptr)->QResizeEvent_shell::__shell()->tryDeleteShell(typeid(QResizeEvent));
}

// emitting Virtual overrides (virtualFunctions)
QResizeEvent* QResizeEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QResizeEvent::clone()const", QResizeEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QResizeEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QResizeEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QResizeEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QResizeEvent_shell::__shell()->warnForMethod("QResizeEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QResizeEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QResizeEvent::clone();
        }
    }else{
        return QResizeEvent::clone();
    }
}

void QResizeEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QResizeEvent::", QResizeEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QResizeEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QResizeEvent_shell::__shell()->warnForMethod("QResizeEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QResizeEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QResizeEvent_access::__qt_assign_cref_QResizeEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QResizeEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QResizeEvent>(__jni_env, other0);
    QResizeEvent::operator=(__qt_other0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QResizeEvent_access::__qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QResizeEvent* __qt_return_value = QResizeEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QResizeEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QResizeEvent(QResizeEvent)
void __qt_construct_QResizeEvent_cref_QResizeEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QResizeEvent(QResizeEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QResizeEvent& __qt_arg__1 = qtjambi_cast<const QResizeEvent& >(__jni_env, arg__1);
    QResizeEvent *__qt_this = new(__qtjambi_ptr) QResizeEvent_shell(__qt_arg__1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QResizeEvent::QResizeEvent(QResizeEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QResizeEvent_initialize_1native__Lio_qt_gui_QResizeEvent_2Lio_qt_gui_QResizeEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QResizeEvent::QResizeEvent(QResizeEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QResizeEvent_cref_QResizeEvent, sizeof(QResizeEvent_shell), typeid(QResizeEvent), true, &deleter_QResizeEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QResizeEvent(QSize,QSize)
void __qt_construct_QResizeEvent_cref_QSize_cref_QSize(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QResizeEvent(QSize,QSize)")
    jobject size0 = __java_arguments[0].l;
    const QSize& __qt_size0 = qtjambi_cast<const QSize& >(__jni_env, size0);
    jobject oldSize1 = __java_arguments[1].l;
    const QSize& __qt_oldSize1 = qtjambi_cast<const QSize& >(__jni_env, oldSize1);
    QResizeEvent *__qt_this = new(__qtjambi_ptr) QResizeEvent_shell(__qt_size0, __qt_oldSize1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QResizeEvent::QResizeEvent(QSize,QSize)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QResizeEvent_initialize_1native__Lio_qt_gui_QResizeEvent_2Lio_qt_core_QSize_2Lio_qt_core_QSize_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject size0,
 jobject oldSize1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QResizeEvent::QResizeEvent(QSize,QSize)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = size0;
        arguments[1].l = oldSize1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QResizeEvent_cref_QSize_cref_QSize, sizeof(QResizeEvent_shell), typeid(QResizeEvent), true, &deleter_QResizeEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QResizeEvent_shell
void __qt_destruct_QResizeEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QResizeEvent")
    reinterpret_cast<QResizeEvent_shell*>(ptr)->~QResizeEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QResizeEvent::oldSize()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QResizeEvent_oldSize_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QResizeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QResizeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QResizeEvent::oldSize()const", __qt_this)
        const QSize& __qt_return_value = __qt_this->oldSize();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QResizeEvent::operator=(QResizeEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QResizeEvent_assign_1native_1cref_1QResizeEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QResizeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QResizeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QResizeEvent::operator=(QResizeEvent)", __qt_this)
        static_cast<QResizeEvent_access*>(__qt_this)->__qt_assign_cref_QResizeEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QResizeEvent::size()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QResizeEvent_size_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QResizeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QResizeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QResizeEvent::size()const", __qt_this)
        const QSize& __qt_return_value = __qt_this->size();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QResizeEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QResizeEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QResizeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QResizeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QResizeEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QResizeEvent_access*>(__qt_this)->__qt_clone_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QResizeEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QResizeEvent>("QResizeEvent", "io/qt/gui/QResizeEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/gui/QResizeEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QResizeEvent, {
        ConstructorInfo(&__qt_construct_QResizeEvent_cref_QResizeEvent, "Lio/qt/gui/QResizeEvent;")
       ,ConstructorInfo(&__qt_construct_QResizeEvent_cref_QSize_cref_QSize, "Lio/qt/core/QSize;Lio/qt/core/QSize;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QResizeEvent);
    registerSizeOfShell(typeId, sizeof(QResizeEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QResizeEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
